Learn R Programming

deal (version 1.2-34)

numbermixed: The number of possible networks

Description

Calculates the number of different directed acyclic graphs for a set of discrete and continuous nodes.

Usage

numbermixed(nd,nc)

Arguments

nd
an integer, which gives the number of discrete nodes.
nc
an integer, which gives the number of continuous nodes.

Value

  • A numeric containing the number of directed acyclic graphs with the given node configuration.

encoding

latin1

Details

No arrows are allowed from continuous nodes to discrete nodes. Cycles are not allowed. The number of networks is given by Bottcher (2003), using the result in Robinson (1977). When nd+nc>15, the procedure is quite slow.

References

Bottcher, S.G. (2003). Learning Conditional Gaussian Networks. http://www.math.aau.dk/~alma. Aalborg University, 2003. Robinson, R.W. (1977). Counting unlabeled acyclic digraphs, Lecture Notes in Mathematics, 622: Combinatorial Mathematics. Further information about deal can be found at: http://www.math.aau.dk/~dethlef/novo/deal.

Examples

Run this code
numbermixed(2,2)
numbermixed(5,10)

Run the code above in your browser using DataLab