Learn R Programming

deal (version 1.2-34)

unique.networkfamily: Makes a network family unique.

Description

Removes networks that are equal or equivalent to networks already in the network family.

Usage

## S3 method for class 'networkfamily':
unique(x,incomparables=FALSE,equi=FALSE,timetrace=FALSE,epsilon=1e-12,...)

Arguments

x
an object of class networkfamily.
incomparables
a logical, but has no effect.
equi
a logical. If TRUE, also equivalent networks are thrown out (i.e. if their score is within epsilon from another network).
timetrace
a logical. If TRUE, prints some timing information on the screen.
epsilon
a numeric, which measures how close network scores are allowed to be from each other to be 'equivalent'.
...
further arguments (no effect)

encoding

latin1

References

Further information about deal can be found at: http://www.math.aau.dk/~dethlef/novo/deal.

Examples

Run this code
data(rats)
rats.nwf <- networkfamily(rats)
rats.nwf2<- unique(getnetwork(rats.nwf),equi=TRUE)

Run the code above in your browser using DataLab